@@ -1,4 +1,4 @@
-## ---- echo = FALSE, message = FALSE---------------------------------------------------------------
+## ----echo = FALSE, message = FALSE----------------------------------------------------------------
 knitr::opts_chunk$set(comment = "")
 options(width = 100, max.print = 100)
 set.seed(123456)
@@ -38,22 +38,22 @@ print(pg <- dplyr::bind_rows(
   expand_tibble(proc = "mean", trim = c(0.1, 0.2))
 ))
 
-## ---- eval=FALSE----------------------------------------------------------------------------------
-#  1.  convert dg to R-functions  {g_1, ..., g_k}
-#  2.  convert pg to R-functions  {f_1, ..., f_L}
-#  3.  initialize result object
-#  4.  append dg and pg to the result object
-#  5.  t1 = current.time()
-#  6.  for g in  {g_1, ..., g_k}
-#  7.      for r in 1:replications (optionally in a parallel manner)
-#  8.          data = g()
-#  9.          for f in  {f_1, \ldots, f_L}
-#  10.             append f(data) to the result object (optionally apply a post-analyze-function)
-#  11.         optionally append data to the result object
-#  12.      optionally summarize the result object over all
-#           replications but separately for f_1, ..., f_L (and optional group variables)
-#  13. t2 = current.time()
-#  14. Estimate the number of replications per hour from t1 and t2
+## ----eval=FALSE-----------------------------------------------------------------------------------
+# 1.  convert dg to R-functions  {g_1, ..., g_k}
+# 2.  convert pg to R-functions  {f_1, ..., f_L}
+# 3.  initialize result object
+# 4.  append dg and pg to the result object
+# 5.  t1 = current.time()
+# 6.  for g in  {g_1, ..., g_k}
+# 7.      for r in 1:replications (optionally in a parallel manner)
+# 8.          data = g()
+# 9.          for f in  {f_1, \ldots, f_L}
+# 10.             append f(data) to the result object (optionally apply a post-analyze-function)
+# 11.         optionally append data to the result object
+# 12.      optionally summarize the result object over all
+#          replications but separately for f_1, ..., f_L (and optional group variables)
+# 13. t2 = current.time()
+# 14. Estimate the number of replications per hour from t1 and t2
 
 ## -------------------------------------------------------------------------------------------------
 dg <- expand_tibble(fun = "rnorm", n = 10, mean = 1:2)
@@ -243,12 +243,12 @@ eval_tibbles(dg, pg, replications = 10^3, discard_generated_data = TRUE,
                    ncpus = 1,
                    summary_fun = list(mean = mean))
 
-## ---- eval = FALSE--------------------------------------------------------------------------------
-#  6.  for g in  {g_1, ..., g_k}
-#  7.      for r in 1:replications (optionally in a parallel manner)
-#  8.          data = g()
-#  9.          for f in  {f_1, \ldots, f_L}
-#  10.             append f(data) to the result object (optionally apply a post-analyze-function)
+## ----eval = FALSE---------------------------------------------------------------------------------
+# 6.  for g in  {g_1, ..., g_k}
+# 7.      for r in 1:replications (optionally in a parallel manner)
+# 8.          data = g()
+# 9.          for f in  {f_1, \ldots, f_L}
+# 10.             append f(data) to the result object (optionally apply a post-analyze-function)
 
 ## -------------------------------------------------------------------------------------------------
 EVAL <- FALSE
@@ -256,18 +256,18 @@ if (Sys.getenv("NOT_CRAN") == "true") {
   EVAL <- TRUE
 }
 
-## ---- eval = EVAL---------------------------------------------------------------------------------
+## ----eval = EVAL----------------------------------------------------------------------------------
 dg <- dplyr::bind_rows(
   expand_tibble(fun = c("rnorm"), mean = 1, n = c(10L, 100L)),
   expand_tibble(fun = c("rexp"), rate = 1, n = c(10L, 100L))
 )
 dg
 
-## ---- eval = EVAL---------------------------------------------------------------------------------
+## ----eval = EVAL----------------------------------------------------------------------------------
 pg <- expand_tibble(proc = c("mean", "median"))
 pg
 
-## ---- eval = EVAL---------------------------------------------------------------------------------
+## ----eval = EVAL----------------------------------------------------------------------------------
 et <- eval_tibbles(dg, pg, replications = 10^4, ncpus = 2)
 
 et$simulation %>%
@@ -275,7 +275,7 @@ et$simulation %>%
   geom_density(alpha = 0.3) +
   facet_wrap(~ proc)
 
-## ---- eval = EVAL---------------------------------------------------------------------------------
+## ----eval = EVAL----------------------------------------------------------------------------------
 bootstrap_ci <- function(x, conf.level, R = 999) {
   b <- boot::boot(x, function(d, i) {
     n <- length(i)
@@ -287,7 +287,7 @@ bootstrap_ci <- function(x, conf.level, R = 999) {
   boot::boot.ci(b, conf = conf.level, type = "all")
 }
 
-## ---- eval = EVAL---------------------------------------------------------------------------------
+## ----eval = EVAL----------------------------------------------------------------------------------
 post_analyze <- function(o, .truth) {
   if (class(o) == "htest") {
   #post-process the object returned by t.test
@@ -301,8 +301,8 @@ post_analyze <- function(o, .truth) {
   #post-process the object returned by boot.ci
     method = c("normal", "basic", "student", "percent", "bca")
     ret = o[method]
-    lower = unlist(purrr::map(ret, ~dplyr::nth(.x, -2)))
-    upper = sapply(ret, dplyr::last)
+    lower = unlist(purrr::map(ret, ~dplyr::nth(.x[1,], -2)))
+    upper = unlist(purrr::map(ret, ~dplyr::nth(.x[1,], -1)))
     type = paste("boot", method, sep = "_")
 
     return(
@@ -319,7 +319,7 @@ post_analyze <- function(o, .truth) {
   }
 }
 
-## ---- eval = EVAL---------------------------------------------------------------------------------
+## ----eval = EVAL----------------------------------------------------------------------------------
 dg <- dplyr::bind_rows(
   simTool::expand_tibble(fun = "rnorm", n = 10L, mean = 0, sd = sqrt(3), .truth = 0),
   simTool::expand_tibble(fun = "runif", n = 10L, max = 6, .truth = 3),
@@ -327,14 +327,14 @@ dg <- dplyr::bind_rows(
 )
 dg
 
-## ---- eval = EVAL---------------------------------------------------------------------------------
+## ----eval = EVAL----------------------------------------------------------------------------------
 pg <- simTool::expand_tibble(
   proc = c("t.test","bootstrap_ci"),
   conf.level = c(0.9, 0.95)
 )
 pg
 
-## ---- eval = EVAL---------------------------------------------------------------------------------
+## ----eval = EVAL----------------------------------------------------------------------------------
 et <- eval_tibbles(dg, pg,
   replications = 10^3, ncpus = 2,
   cluster_global_objects = "post_analyze",
@@ -344,7 +344,7 @@ et <- eval_tibbles(dg, pg,
 )
 et
 
-## ---- eval = EVAL, fig.width=13-------------------------------------------------------------------
+## ----eval = EVAL, fig.width=13--------------------------------------------------------------------
 et$simulation %>%
   ggplot(aes(x = fun, y = value, group = type, fill = type, label = round(value, 2))) +
   geom_col(position = "dodge") +
@@ -352,7 +352,7 @@ et$simulation %>%
   theme(legend.position = "bottom") + 
   facet_grid(aspect ~ conf.level, scales = "free")
 
-## ---- eval = EVAL---------------------------------------------------------------------------------
+## ----eval = EVAL----------------------------------------------------------------------------------
 t_test = function(x, conf.level){
   tt <- t.test(x, conf.level = conf.level)
   
@@ -371,8 +371,8 @@ bootstrap_ci <- function(x, conf.level, R = 999) {
   ci <- boot::boot.ci(b, conf = conf.level, type = "all")
   method = c("normal", "basic", "student", "percent", "bca")
   ret = ci[method]
-  lower = unlist(purrr::map(ret, ~dplyr::nth(.x, -2)))
-  upper = sapply(ret, dplyr::last)
+  lower = unlist(purrr::map(ret, ~dplyr::nth(.x[1,], -2)))
+  upper = unlist(purrr::map(ret, ~dplyr::nth(.x[1,], -1)))
   type = paste("boot", method, sep = "_")
   
   # unify return
@@ -396,7 +396,7 @@ et <- eval_tibbles(dg, pg,
 )
 et
 
-## ---- eval = EVAL---------------------------------------------------------------------------------
+## ----eval = EVAL----------------------------------------------------------------------------------
 grps <- et$simulation %>% 
   select(-replications) %>% 
   select(fun:type) %>% 
